|PyPI| |Docs| |Build Status| |Coverage|

.. |PyPI| image:: https://img.shields.io/pypi/v/anndata.svg
   :target: https://pypi.org/project/anndata
.. |Docs| image:: https://readthedocs.org/projects/anndata/badge/?version=latest
   :target: https://anndata.readthedocs.io
.. |Build Status| image:: https://travis-ci.org/theislab/anndata.svg?branch=master
   :target: https://travis-ci.org/theislab/anndata
.. |Coverage| image:: https://codecov.io/gh/theislab/anndata/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/anndata

anndata - Annotated Data
========================

Install from `PyPI <https://pypi.python.org/pypi/anndata/>`__ via ``pip install anndata``.

Read the `documentation <https://anndata.readthedocs.io>`_.
